# extras

Extras directory that contains functions that need additional dependencies to work.

| File          | Description |
| :-----------: | :---------: |
| dispersion.py | Dispersion correction |
| fods.py       | FOD generation |
| libxc.py      | Use Libxc functionals |
| torch.py      | Faster FFT operators using Torch |
| viewer.py     | Notebook display functions |
